@@ -1,4 +1,4 @@
-# Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
+# Copyright (c) 2012 Riverbank Computing Limited <info@riverbankcomputing.com>
 # 
 # This file is part of PyQt.
 # 
@@ -14,13 +14,8 @@
 # GPL Exception version 1.1, which can be found in the file
 # GPL_EXCEPTION.txt in this package.
 # 
-# Please review the following information to ensure GNU General
-# Public Licensing requirements will be met:
-# http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-# you are unsure which license is appropriate for your use, please
-# review the following information:
-# http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-# or contact the sales department at sales@riverbankcomputing.com.
+# If you are unsure which license is appropriate for your use, please
+# contact the sales department at sales@riverbankcomputing.com.
 # 
 # This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 # WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -36,12 +31,12 @@ import sipconfig
 _pkg_config = {
     'pyqt_bin_dir':      '/usr/bin',
     'pyqt_config_args':  '--confirm-license --verbose',
-    'pyqt_mod_dir':      '/usr/lib/python2.6/site-packages/PyQt4',
-    'pyqt_modules':      'QtCore QtGui QtHelp QtMultimedia QtNetwork QtDeclarative QtOpenGL QtScript QtScriptTools QtSql QtSvg QtTest QtWebKit QtXml QtXmlPatterns phonon QtDesigner',
+    'pyqt_mod_dir':      '/usr/lib/python2.7/site-packages/PyQt4',
+    'pyqt_modules':      'QtCore QtGui QtHelp QtMultimedia QtNetwork QtDBus QtDeclarative QtOpenGL QtScript QtScriptTools QtSql QtSvg QtTest QtWebKit QtXml QtXmlPatterns phonon QtDesigner',
     'pyqt_sip_dir':      '/usr/share/sip/PyQt4',
-    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -x PyQt_qreal_double -t Qt_4_7_0 -x Py_v3 -g',
-    'pyqt_version':      0x040801,
-    'pyqt_version_str':  '4.8.1',
+    'pyqt_sip_flags':    '-x VendorID -t WS_X11 -x PyQt_NoPrintRangeBug -x PyQt_qreal_double -t Qt_4_8_4 -x Py_v3 -g',
+    'pyqt_version':      0x040906,
+    'pyqt_version_str':  '4.9.6',
     'qt_data_dir':       '/usr/lib/qt',
     'qt_dir':            '/usr/lib/qt',
     'qt_edition':        'free',
@@ -49,7 +44,7 @@ _pkg_config = {
     'qt_inc_dir':        '/usr/lib/qt/include',
     'qt_lib_dir':        '/usr/lib/qt/lib',
     'qt_threaded':       1,
-    'qt_version':        0x040700,
+    'qt_version':        0x040804,
     'qt_winconfig':      'shared'
 }
 
@@ -58,6 +53,7 @@ _default_macros = {
     'AR':                       'ar cqs',
     'CC':                       'gcc',
     'CFLAGS':                   '-pipe',
+    'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
     'CFLAGS_EXCEPTIONS_OFF':    '',
@@ -66,7 +62,7 @@ _default_macros = {
     'CFLAGS_MT_DBG':            '',
     'CFLAGS_MT_DLL':            '',
     'CFLAGS_MT_DLLDBG':         '',
-    'CFLAGS_RELEASE':           '-O2 -march=armv4t -pipe  -O2',
+    'CFLAGS_RELEASE':           '-O2',
     'CFLAGS_RTTI_OFF':          '',
     'CFLAGS_RTTI_ON':           '',
     'CFLAGS_SHLIB':             '-fPIC',
@@ -76,10 +72,11 @@ _default_macros = {
     'CFLAGS_WARN_OFF':          '-w',
     'CFLAGS_WARN_ON':           '-Wall -W',
     'CHK_DIR_EXISTS':           'test -d',
-    'CONFIG':                   'qt warn_on release incremental link_prl',
+    'CONFIG':                   'qt warn_on release incremental link_prl gdb_dwarf_index',
     'COPY':                     'cp -f',
     'CXX':                      'g++',
     'CXXFLAGS':                 '-pipe',
+    'CXXFLAGS_APP':             '',
     'CXXFLAGS_CONSOLE':         '',
     'CXXFLAGS_DEBUG':           '-g',
     'CXXFLAGS_EXCEPTIONS_OFF':  '',
@@ -88,7 +85,7 @@ _default_macros = {
     'CXXFLAGS_MT_DBG':          '',
     'CXXFLAGS_MT_DLL':          '',
     'CXXFLAGS_MT_DLLDBG':       '',
-    'CXXFLAGS_RELEASE':         '-O2 -march=armv4t -pipe  -O2',
+    'CXXFLAGS_RELEASE':         '-O2',
     'CXXFLAGS_RTTI_OFF':        '',
     'CXXFLAGS_RTTI_ON':         '',
     'CXXFLAGS_SHLIB':           '-fPIC',
@@ -112,7 +109,7 @@ _default_macros = {
     'LFLAGS_DLL':               '',
     'LFLAGS_OPENGL':            '',
     'LFLAGS_PLUGIN':            '-shared',
-    'LFLAGS_RELEASE':           '-Wl,-O1',
+    'LFLAGS_RELEASE':           ' -Wl,-O1',
     'LFLAGS_RPATH':             '-Wl,-rpath,',
     'LFLAGS_SHLIB':             '-shared',
     'LFLAGS_SONAME':            '-Wl,-soname,',
@@ -129,7 +126,7 @@ _default_macros = {
     'LIBS_CORE':                '',
     'LIBS_GUI':                 '',
     'LIBS_NETWORK':             '',
-    'LIBS_OPENGL':              '-lGLU -lGL',
+    'LIBS_OPENGL':              '-lGL',
     'LIBS_RT':                  '',
     'LIBS_RTMT':                '',
     'LIBS_THREAD':              '-lpthread',
@@ -395,3 +392,15 @@ class QAxContainerModuleMakefile(QtGuiModuleMakefile):
             kw["qt"] = ["QtCore", "QtGui", "QAxContainer"]
 
         QtGuiModuleMakefile.__init__(self, *args, **kw)
+
+
+class QtDBusModuleMakefile(QtCoreModuleMakefile):
+    """The Makefile class for modules that %Import QtDBus.
+    """
+    def __init__(self, *args, **kw):
+        """Initialise an instance of a module Makefile.
+        """
+        if "qt" not in kw:
+            kw["qt"] = ["QtCore", "QtDBus"]
+
+        QtCoreModuleMakefile.__init__(self, *args, **kw)
